/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import ClayButton from '@clayui/button';
import {useModal} from '@clayui/modal';
import PropTypes from 'prop-types';
import React, {useCallback, useEffect, useState} from 'react';

import {SCHEMA_SELECTED_EVENT} from '../constants';
import ExportModal from './ExportModal';

function Export({
	formExportDataQuerySelector,
	formExportURL,
	portletNamespace,
}) {
	const [disable, setDisable] = useState(true);
	const [visible, setVisible] = useState(false);
	const {observer, onClose} = useModal({
		onClose: () => setVisible(false),
	});

	const onButtonClick = useCallback(
		(event) => {
			event.preventDefault();

			setVisible(true);
		},
		[setVisible]
	);

	useEffect(() => {
		function handleSchemaChange(event) {
			if (event.schema) {
				setDisable(false);
			}
		}
		Liferay.on(SCHEMA_SELECTED_EVENT, handleSchemaChange);

		return () => Liferay.detach(SCHEMA_SELECTED_EVENT, handleSchemaChange);
	}, [portletNamespace]);

	return (
		<>
			<ClayButton
				disabled={disable}
				displayType="primary"
				id={`${portletNamespace}saveTemplate`}
				onClick={onButtonClick}
				type="submit"
			>
				{Liferay.Language.get('export')}
			</ClayButton>

			{visible && (
				<ExportModal
					closeModal={onClose}
					formDataQuerySelector={formExportDataQuerySelector}
					formSubmitURL={formExportURL}
					namespace={portletNamespace}
					observer={observer}
				/>
			)}
		</>
	);
}

Export.propTypes = {
	formExportDataQuerySelector: PropTypes.string.isRequired,
	formExportURL: PropTypes.string.isRequired,
	portletNamespace: PropTypes.string.isRequired,
};

export default Export;
