/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import ClayButton from '@clayui/button';
import ClayIcon from '@clayui/icon';
import ClayModal from '@clayui/modal';
import PropTypes from 'prop-types';
import React from 'react';

import {exportStatus, fetchExportedFile} from '../BatchPlannerExport';
import Poller from '../Poller';
import ExportModalBody from './ExportModalBody';

const ExportModal = ({
	closeModal,
	formDataQuerySelector,
	formSubmitURL,
	observer,
}) => {
	const {
		downloadFile,
		errorMessage,
		loading,
		percentage,
		ready: readyToDownload,
	} = Poller(
		formDataQuerySelector,
		formSubmitURL,
		exportStatus,
		fetchExportedFile
	);

	let modalType;
	let iconType;

	if (readyToDownload) {
		modalType = 'modal-success';
		iconType = 'check-circle-full';
	}
	else if (errorMessage) {
		modalType = 'modal-danger';
		iconType = 'exclamation-full';
	}
	else {
		modalType = 'modal-info';
		iconType = 'info-circle';
	}

	return (
		<ClayModal className={modalType} observer={observer} size="md">
			<ClayModal.Header>
				<ClayIcon className="mr-2" symbol={iconType} />

				{Liferay.Language.get('export-file')}
			</ClayModal.Header>

			<ExportModalBody
				errorMessage={errorMessage}
				percentage={percentage}
				readyToDownload={readyToDownload}
			/>

			<ClayModal.Footer
				last={
					<ClayButton.Group spaced>
						<ClayButton
							disabled={loading}
							displayType="secondary"
							onClick={closeModal}
						>
							{Liferay.Language.get('cancel')}
						</ClayButton>

						<ClayButton
							disabled={!readyToDownload}
							displayType={
								readyToDownload ? 'success' : 'primary'
							}
							onClick={downloadFile}
						>
							{loading && (
								<span className="inline-item inline-item-before">
									<span
										aria-hidden="true"
										className="loading-animation"
									></span>
								</span>
							)}

							{Liferay.Language.get('download')}
						</ClayButton>
					</ClayButton.Group>
				}
			/>
		</ClayModal>
	);
};

ExportModal.propTypes = {
	closeModal: PropTypes.func.isRequired,
	formDataQuerySelector: PropTypes.string.isRequired,
	formSubmitURL: PropTypes.string.isRequired,
	namespace: PropTypes.string.isRequired,
	observer: PropTypes.object.isRequired,
};

export default ExportModal;
